function [y] = akfrader(x,M)
//AKFRADER  auto correlation calculation by the method of Rader
//
//Y=AKFRADER(X,[M])
//
//X: stationary random process (Vector)
//Y: auto correlation (Vector of length M)
//M: number for sequence splitting
//
//Literature:
//Kammeyer, Karl Dirk
//"DIGITALE SIGNALVERARBEITUNG : Filterung und Spektralanalyse"
//Teubner-Verlag 1989, Teubner-Studienbcher: Elektrotechnik
//ISBN 3-519-06122-8

// Ouput variables initialisation (not found in input variables)
y=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==1 then
  lx = max(size(mtlb_double(x)));
  M = 64;
  Nges = floor(lx/mtlb_double(M));
else
  lx = max(size(mtlb_double(x)));
  Nges = floor(lx/mtlb_double(M));
end;
// CROPPING
x = mtlb_e(x,:);
// Spaltenvektor erzwingen
x = mtlb_e(x,mtlb_imp(1,mtlb_double(M)*Nges));
lx = max(size(mtlb_double(x)));

x = [matrix(mtlb_double(x),M,Nges);zeros(real(mtlb_double(M)),real(Nges))];
// Teilfolgenzerlegung und M-Nullen
// anhngen

SX = mtlb_fft(x);
// Spaltenweise 2*M-DFT

SXI = SX(:,mtlb_imp(1,mtlb_s(Nges,1)));
SXI1 = SX(:,mtlb_imp(2,Nges));

kx = mtlb_imp(0,1,mtlb_s(2*mtlb_double(M),1));
kx = (-1) .^kx;
kx=meshgrid(kx,1:1:Nges-1).';
// Alternierende Spektralfunktion

S = mtlb_sum((conj(SXI) .*mtlb_a(SXI,SXI1 .*mtlb_double(kx))).');
y = real(mtlb_ifft(S)) ./lx;
y = y(mtlb_imp(1,mtlb_double(M)));
// Prozedurende
endfunction
