function [xi,yi] = akima(x,y,K)
//AKIMA Akima-Interpolation
// 
//[XI,YI]=AKIMA(X,Y,K);
// 
//Die gegebenen Punkte (X,Y) werden durch Polynome vom Grad 3
//angenhert. Im Gegensatz zur  Spline-Interpolation wird die
//zweite Ableitung nicht bercksichtigt ! Das Auftreten von "WIGGLES"
//(berschwinger) wird weitestgehend unterdrckt.

// Ouput variables initialisation (not found in input variables)
xi=[];
yi=[];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

xback=x; yback=y;
N=length(x);
[x,y,st]=extrapol(x,y);
t=zeros(st);
tcase1=t;
tcase2=t;
boole1=t;
boole2=t;

tcase1(3:N+2)=0.5 .*(st(3:N+2) +  st(4:N+3));	// Berechnung der Polynomsteigungen
tcase2(3:N+2)=(abs(st(4:N+3)-st(3:N+2)).*st(2:N+1) + abs(st(2:N+1)-st(1:N)) .*st(3:N+2)) ./(abs(st(4:N+3)-st(3:N+2))+abs(st(2:N+1)-st(1:N)));

boole1(3:N+2)=((st(1:N)==st(2:N+1)) & (st(3:N+2)==st(4:N+3)));
boole2(3:N+2)=(~(boole1(3:N+2)));

t=(tcase1 .*(bool2s(boole1).')) + (tcase2 .*(bool2s(boole2).'));
x=[x(3:N+2),0,0,0,0];				// Rckindizierung
y=[y(3:N+2),0,0,0,0];
t=[t(3:N+2),0,0,0,0];
A=y(1:N-1); B=t(1:N-1);				// Berechnung der Polynomkoeffizienten
C=(3*st(3:N+1)-2*t(1:N-1)-t(2:N)) ./(x(2:N) - x(1:N-1));
D=(t(1:N-1) + t(2:N) - 2 .*st(3:N+1)) ./((x(2:N) - x(1:N-1)) .^2);
DCBA=[D;C;B;A];

x=xback;y=yback;
dxstep=diff(x)/K;				// Polynom-Auswertungen
yi=[]; xi=[];
for z=1:(N-1),
	xmom=x(z)+dxstep(z) .*(1:1:K);
	ymom=polyval(DCBA(:,z),(xmom - x(z)));
	xi=[xi,xmom]; yi=[yi,ymom];
end;
endfunction


function [xn,yn,st] = extrapol(x,y) 
//EXTRAPOL  Extrapolations-Hilfsprozedur fr Akima-Interpolation
// 
//[XN,YN,ST]=EXTRAPOL(X,Y)
// 
//Berechnung der nchsten zwei linken und rechten Nachbarn der
//Funktion y=f(x) durch Extrapolation sowie der 1. Ableitung
//(Rckwrtsdifferenzen)

// Ouput variables initialisation (not found in input variables)
xn=[];
yn=[];
st=[];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

N=length(x);
x=[0,0,x,0,0]; y=[0,0,y,0,0];
st=[0,0,zeros(1,N),0,0];
x(2)=x(3)+x(4)-x(5);
x(1)=x(2)+x(3)-x(4);
x(N+3)=x(N+2)+x(N+1)-x(N);
x(N+4)=x(N+3)+x(N+2)-x(N+1);
st(3:N+1)=diff(y(3:N+2)) ./diff(x(3:N+2));
y(2)=(x(3) - x(2))*(st(4)-2*st(3)) + y(3);
st(2)=(y(3)-y(2))/(x(3)-x(2));
y(1)=(x(2)-x(1))*(st(3)-2*st(2)) + y(2);
st(1)=(y(2)-y(1))/(x(2)-x(1));
y(N+3)=(2*st(N+1)-st(N))*(x(N+3)-x(N+2)) + y(N+2);
st(N+2)=(y(N+3)-y(N+2))/(x(N+3)-x(N+2));
y(N+4)=(2*st(N+2) - st(N+1))*(x(N+4)-x(N+3)) + y(N+3);
st(N+3)=(y(N+4)-y(N+3))/(x(N+4)-x(N+3));
xn=x; yn=y;
endfunction
