function [yr,yg,yb] = bmpcolor(datei)
// BMPCOLORreading RGB bitmaps
// 
//           [YR,YG,YB]=BMPCOLOR(DATEI)
//   or      L=BMPCOLOR(DATEI)
// 
// Function to read RGB bitmaps.
// YR,YG,YB  : RGB-value matrices
// DATEI     : full pathname of RGB bitmap file


// Ouput variables initialisation (not found in input variables)
yr=[];
yg=[];
yb=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==0 then
  datei=tk_getfile('*.bmp','c:\',title='Load RGB bitmap');
  if isempty(datei) then
    disp("Loading Abort !");
    yr = [];  yg = [];  yb = [];
    return;
  end;
end;

justlumi="n";
if %nargout==3 then
  justlumi = "n";
end;
if %nargout==1 then
  justlumi = "y";
end;
[fid,errmsg] = mopen(datei,"rb");  // Datei ffnen
if errmsg<0 then
  return;
end

bmpb=mget(2,"uc",fid);
// BMP-Format ?
if bmpb~=[66,77] then
  disp("Das ist kein BMP-Bild!");
  mclose(fid);
  return;
end;

status = mseek(18,fid,"set");
a = mget(2,"uc",fid);
// Breite
brte = a(2)*256+a(1);
status = mseek(22,fid,"set");
// L.37: No simple equivalent, so mtlb_fread() is called
b=mget(2,"uc",fid);
// Hhe
hhe = b(2)*256+b(1);
brtakt = 4*ceil((3*brte)/4);        // BMP-Format kennt nur durch 4 teilbare Bildbreiten
status = mseek(54,fid,"set");
// L.42: No simple equivalent, so mtlb_fread() is called
[y,count] = mtlb_fread(fid,[brtakt,hhe],"uchar");        // Einlesen der Pixelmatrizen
mclose(fid);                                             // Schlieen des BMP-Files

k1b = 1:3:3*brte;                   // Indices der Blau-, Grn-
k2b = 2:3:3*brte;                   // und Rotanteile (RGBQUAD)
k3b = 3:3:3*brte;

// Rotation um 90 gegen Uhrzeigersinn
yb = y(k1b,:); 
[m0,n0]=size(yb);
yb=yb.';
yb=yb(n0:-1:1,:);

yg = y(k2b,:);
yg=yg.';
yg=yg(n0:-1:1,:);

yr = y(k3b,:);
yr=yr.';
yr=yr(n0:-1:1,:);

if asciimat(justlumi)==asciimat("y") then
  // Conversion into a luminance matrix
  yr = 0.299 .*yr + 0.587 .*yg + 0.114 .*yb;
end;
endfunction
