function [y,map] = bmpread(datei) 
// BMPREAD   Read 8-Bit Bitmap
// 
// [Y,[MAP]]=BMPREAD([DATEI])
// 
// Reading an uncompressed Bitmap with 8-Bit Quantization depth
// Y    : The picture matrix
// MAP  : the colormap
// DATEI: full pathname of the bitmap (optional)
//
// The picture can be display in SciLab like this:
// f=gcf();
// f.color_map=MAP;
// Matplot(Y);


// Ouput variables initialisation (not found in input variables)
y=[];
map=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0);

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==0 then
  datei=tk_getfile('*.bmp','c:\',title='Load Bitmap File');
  if isempty(datei) then
    disp("Loading Abort !");
    y = [];
    map = [];
    return;
  end;
end;

mapyes = "y";

fid = mopen(datei,"rb");   // Bitmap ffnen
bmpb=mget(2,"uc",fid);

// BMP-Format ?
if bmpb~=[66,77] then
  disp("Das ist kein BMP-Bild!");
  mclose(fid);
  return;
end;
status = mseek(10,fid,"set");
// berprfung der Palettengre
posi = mget(2,"uc",fid);
// Palettengre
palli = posi(2)*256+posi(1);

if palli~=1078 then
  disp("Keine 8-Bit-Farbpalette !");
  mclose(fid);
  return;
end;
status = mseek(18,fid,"set");
a = mget(2,"uc",fid);           // Breite
brte = a(2)*256+a(1);
brtakt = 4*ceil(brte/4);        // Breite mod 4 mu bei BMP Null sein
status = mseek(22,fid,"set");
b = mget(2,"uc",fid);           // Hhe
hhe = b(2)*256+b(1);

if asciimat(mapyes)==asciimat("y") then
  // Einlesen der Farbpalette 
  status = mseek(53,fid,"set");
  [map,count] = mtlb_fread(fid,[4,256],"uchar");

  map = map.';
  map = map(:,2:4)/256;
  map = map(:,$:-1:1);
  // BGR -> RGB
  dmap = mtlb_diff(map,1,firstnonsingleton(map)) .^2;
  // Reduzierung der Palettengre auf Mindestma
  dmap = [1,mtlb_mean(dmap.')];
  k = 1:1:256;
  kselect = k(mtlb_logic(mtlb_double(dmap),"~=",0));
  if ~isempty(kselect) then
    %v02_1 = kselect;  kselect = mtlb_max(%v02_1,firstnonsingleton(%v02_1));
    map = map(mtlb_imp(1,kselect),:);  // reduzierte Farbpalette
  end;
end;

status = mseek(palli,fid,"set");
// Zeiger wird zu Beginn der Pixeltabelle gelegt
[y,count] = mtlb_fread(fid,[brtakt,hhe],"uchar");
mclose(fid);
// MATLAB: rot90 (Rotation um 90)
[m0,n0]=size(y);
y=y.';
y=y(n0:-1:1,:);
y = y(:,1:1:brte);
y = y+1;

endfunction
