function [A,GAIN]=burg(x,R)
// BURG	AR-Model by the method of Burg
//
//		[A,GAIN]=burg(X,R)
//
//		AR-Model describing a stationary process X based upon the
//
//				BURG-Method
//
//		R is the number of iterations. Default of this
//		optional argument is R=8.
//		The coefficients of the denominator and the Gain
//		are calculated. 
//
//		Hint:
//			With [H,W]=mtlb_freqz([GAIN],A,N);
//			you get the tranfer function in
//			the Fourier area.
//
// 		Literature:
// 			Kammeyer, Karl Dirk
// 			"DIGITALE SIGNALVERARBEITUNG : Filterung und Spektralanalyse"
// 			Teubner-Verlag 1989, Teubner-Studienbcher: Elektrotechnik
// 			ISBN 3-519-06122-8

A=[];
Gain=[];

[%nargout,%nargin] = argn(0);
if %nargin==1 then
  R=8;
end; 

x=x(:);
N=length(x);


ek0=double(x);						// Initialization
b0=double(x);
A=[1.0];
A=double(A);
s0=sum(abs(x) .^2, 'r') ./N;

for p=1:1:R					  // Iterations
	N=length(ek0);	

	gr=2 .*sum( (ek0(p+1:1:N) .*conj(b0(p:1:N-1))),'r') ./sum( (abs(ek0(p+1:1:N)) .^2) + (abs(b0(p:1:N-1)) .^2),'r');

	ek1=ek0(p+1:1:N) - gr .*b0(p:1:N-1);
	b1=b0(p:1:N-1) - conj(gr) .*ek0(p+1:1:N);
	ak=[A;0.0];
	ak=ak - gr .*conj(ak($:-1:1,:));
	A=ak;

	ek0=ek1;
	b0=b1;
	s0=s0 .*(1 - (abs(gr) .^2));
end

GAIN=sqrt(s0);
endfunction
