function [B,A]=butter(n,filtertype,filterfreq);
// BUTTERWORTH FILTER DESIGN IN Z-DOMAIN
//
//    [B,A]=BUTTER(N)
//    [B,A]=BUTTER(N,ftype)
//    [B,A]=BUTTER(N,Freq);
//    [B,A]=BUTTER(N,ftype,Freq)
//
//    This function calculates the filter coefficients for a butterworth
//    filter in the z-domain, so that the output value of the filter is
//    given by:
//
//    a(1)*y(n) = b(1)*x(n) + b(2)*x(n-1) + ... + b(nb+1)*x(n-nb)
//                          - a(2)*y(n-1) - ... - a(na+1)*y(n-na)
//
//    ftype : Type of butterworth filter ('lp'=Low Pass, 'hp'=High Pass,
//            'bp'=Band Pass, 'sb'=Stop Band). Default is 'lp'.
//    Freq  : scalar or vector. If ftype is 'bp' or 'sb', then a vector is
//            needed.

[%nargout,%nargin]=argn(0);
if %nargin==1 then
  filtertype='lp';
  filterfreq=[0.1,0.25];
end

if %nargin==2 then
  if type(filtertype)~=10 then
    filterfreq=filtertype;
    filtertype='lp';
  else
    filterfreq=[0.1,0.25];
  end
end

if filtertype=='bp' | filtertype=='sb' then
  if length(filterfreq)==1 then
    error('2 element vector for filter frequencies needed !');
    return;
  end
else
  if length(filterfreq)~=2 then
    filterfreq=[filterfreq,0];
  end
end

deltavek=[1E-3,1E-3];
hz=iir(n,filtertype,'butt',filterfreq,deltavek);
A=coeff(denom(hz)); A=A($:-1:1);
B=coeff(numer(hz)); B=B($:-1:1);

endfunction
