function W=cauchy(z,p,modus);
// CAUCHY	Cauchy integral regarding Residuals
//
//		W=CAUCHY(Z,P,[MODUS])
//
//		Z is a complex vector, describing a closed curve.
//		P is a complex scalar, a complex vector or a complex
//		matrix describing points (which can be seen as residuals)
//
//		W is the complex value of the integral and has the same size
//		as P.
//
//		The optional input Argument MODUS, default='y', is responsible
//		for a nice graphical display.
//
//		Example:
//		zcurve=bezier();	// Draw a closed curve
//		x=0.1:0.1:0.9; y=x;
//		[X,Y]=meshgrid(x,y);
//		PZ=X + %i .*Y;
//		W=cauchy(zcurve,PZ);

[%nargout,%nargin]=argn(0);
if %nargin==2,
	modus='y';
end
modus=mtlb_lower(part(modus,1));

z=z(:).';				// make row vector
[zeilp,spalp]=size(p);
p0=p;
p=p(:).';

LZ=length(z);			// Close Polygon
if z(1)~=z(LZ),
	z=[z,z(1)];
	LZ=LZ+1;
end

dz=[0,diff(z)];

DZ=meshgrid(dz,1:1:length(p));
[Z,P]=meshgrid(z,p);
ZP=Z - P;
W=sum( (DZ ./ZP),'c');

W=matrix(W,zeilp,spalp);

if modus~='n',
	SCHW=0.7;
	h=scf();
	plot2d(real(z),imag(z));
	plot2d(real(p0(abs(W)>SCHW)),imag(p0(abs(W)>SCHW)),style=-2);
	plot2d(real(p0(abs(W)<=SCHW)),imag(p0(abs(W)<=SCHW)),style=-3);
end
endfunction