function R=corrcoeff(x,y);
// CORRCOEF
//
//        Correlation Coefficient calculation
//        Two wasy of use are possible:
//
//        1): R=corrcoeff(x,y)
//            corrcoeff is used with two input arguments x and y
//            x and y are vectors and must have the same length.
//            As result you get a scalar value, the correlation
//            coefficient between x and y.
//        2): R=corrcoeff(X);
//            X is a matrix with at least two coulmns. Each column
//            represents a signal. As result you get a square matrix
//            R with so many columns a the input matrix X.
//            The element r(i,j) equals the correlation coefficient
//            between signal i and j.

R=[];
[%nargout, %nargin]=argn(0);

if %nargin==2 then
  x=x(:); y=y(:);
  mx=mean(x);           // Mean Values
  my=mean(y);

  zmx2=mean( (x - mx) .^2);
  zmy2=mean( (y - my) .^2);
  zmxy=mean( (x-mx) .*(y-my));

  R=zmxy ./sqrt(zmx2*zmy2);
end

if %nargin==1 then
  [N,M]=size(x);
  if M<2 then
    disp('If only one input argument is used, it must be a');
    disp('matrix with at least two columns...');
    return;
  end
  zm1=x - meshgrid(mean(x,'r'),1:1:N);
  W0=(zm1.')*zm1;
  W1=sqrt(diag(W0)*diag(W0).');
  R=W0 ./W1;
end
  
endfunction



