function [objzahl,Kp_rest,cs,meanpt]=countobj(w);
// COUNTOBJ
// [objzahl,WNEU,KP_REST,CS]=COUNTOBJ(w)
//
// The matrix w represents abinary image. 
// It contains elements from the set {0,1}.
// This functions counts the objects represented
// by values "1".
//
// The tricky things with objects is always: How do
// you define an object ? This function takes always the
// enclosing shape. When you have a small ring inside a
// large ring, then the inner ring is not counted.
//
// The matrix Kp_rest contains in the 1st row the start positions
// and in the 2nd row the number of values followed, which have been
// used for object counting.
//
// meapt is a matrix with two rows. The 1st row contains the x and the 2nd
// row the y values of the object center points
//
// CS is the contour data of the binary image, generated with
// the SciLab function contour2di.sci
//
// Finally, this function draws a graph showing the counting result.

[%nargout,%nargin]=argn(0);

[zw,sw]=size(w);
[xc,yc]=contour2di(1:1:zw,1:1:sw,full(w),1);
cs=[xc;yc];						// contour data
[KLine,Kpar]=linenumb(cs);

if KLine==0,
	objzahl=0;
	wneu=[]; Kp_rest=[]; cs=[];
	return;
end

if KLine>1,
	i=sqrt(-1);
	// ---------------------------------
	// Get a random Point of every Curve
	// ---------------------------------
	PoRand=[];
	for k=1:1:KLine,
		kselect=(Kpar(1,k)+1):1:(Kpar(1,k)+Kpar(2,k));
		ausw=ceil(length(kselect) .*rand(1,1));
		zeiger=kselect(ausw);
		PoAkt=cs(:,zeiger);
		PoRand=[PoRand;(PoAkt(1) + i .*PoAkt(2))];
	end;
	// ---------------------
	// End of Getting Points
	// ---------------------

	// -----------------------------------------------------------
	// check for enclosing: way integral in complexen plane,
	// Cauchy, Singularity ...
	// -----------------------------------------------------------
	kdel=[];
	kx=1:1:KLine;
	for k=1:1:KLine
		Pref_x=cs(1,Kpar(1,k)+1:Kpar(1,k)+Kpar(2,k));
		Pref_y=cs(2,Kpar(1,k)+1:Kpar(1,k)+Kpar(2,k));		// line integral
		Pref=Pref_x + i .*Pref_y;                      // randomwise choosen
		dP=[0,diff(Pref)];                             // points are singularity
		kselect=kx(kx~=k);
		for m=kselect,
			Q=PoRand(m);
			weg_gral=abs(imag(sum(dP ./(Pref - Q))));
			if weg_gral>1,
				K=[k,m];
				kdel=[kdel;K];
			end
		end
	end
	// --------------------------
	// End of enclosing detection
	// --------------------------

	// curves in 1st column are around curves in 2nd column

	if ~isempty(kdel),
		KR=kdel(:,2);
		

		%v0 = size(mtlb_double(KR));
    %v1 = size(mtlb_double(KR));
    %v2$1 = ones(%v0(1),%v0(2));
    %v3$2 = mtlb_double(KR);
    HKR = sparse([%v2$1(:),%v3$2(:)],ones(%v1(1),%v1(2)),[1,KLine]);
		
		
		HKR=full(HKR);      // number of valid curves
		kguilty=kx(HKR==0);
	else
		kguilty=kx;
	end
else
	kguilty=[1];
end

// --------------------------
// Auswertung und Darstellung
// --------------------------
objzahl=length(kguilty);				// counting results
Kp_rest=Kpar(:,kguilty);				// curve parameters
meanpt=[];                  // matrix with center points
xges=[]; yges=[];
Po_text=[];

f=gcf();
f.figure_name="CountObj Result: "+string(objzahl);
showcs(cs);

for k=1:length(kguilty),
	posakt=Kp_rest(1,k);
	nakt=Kp_rest(2,k);

	xsel=cs(1,posakt+1:posakt+nakt);
	ysel=cs(2,posakt+1:posakt+nakt);
	plot2d(xsel,ysel,style=3);
	Pmit=[mean(xsel);mean(ysel)];
	meanpt=[meanpt,Pmit];				// object center points
	Po_text=[Po_text,PoRand(kguilty(k))];
	xstring(Pmit(1),Pmit(2),string(k));
end
plot2d(meanpt(1,:),meanpt(2,:),style=-3);
f.children.isoview="on";
endfunction

// SUPPORTING FUNCTION
// -------------------
function [K,Kpos]=linenumb(cs);
// LINENUMB
//		[K,Kpos]=LINENUMB(CS)
//
//		number of piecewise continous contour lines.
//		The matrix KPOS contains in the 1st row the
//		Positions of a start of a curve, in the 2nd
//		row the number of points are contained.

[z,s]=size(cs);
spos=1;
K=0;
Kpos=[1];
Nakt=[];
while (spos<s),
	nakt=cs(2,spos);
	Nakt=[Nakt,nakt];
	K=K+1;
	spos=spos+nakt+1;				// Pointer to next segment
	Kpos=[Kpos,spos];
end;
Kpos=Kpos(1:length(Kpos)-1);
Kpos=[Kpos;Nakt];

endfunction
