function [csinfo,pkpu]=csanaly2(cs,DSCHWELLE)
//CSANALY2	more detailled vector analysis
//
//	CSANALY2(CS)			or
//	CSINFO=CSANALY2(CS)		or
//	[PSTA,PCROSS]=CSANALY(CS)
//
//	CS	:	Vector - Data
//
//	CSINFO	:	Each row contains information about one contourline.
//	(1)		:	Height value
//	(2)		:	Number of points
//	(3)		:	1. column index CS-Matrix
//	(4)		:	last column index
//	(5)		:	minimum X value
//	(6)		:	maximum X value
//	(7)		:	minimum Y value
//	(8)		:	maximum Y value
//	(9)		:	Start point (complex)
//	(10)	:	End point (complex)
//	(11)	:	number of neighbours at End #1
//	(12)	:	number of neighbours at End #2
//	(13)-(x):	rows of matrix CSINFO, which are neighbours
//
//	PSTA	:	coordinates of line end points
//	PCROSS	:	coordinates of crossing points

[%nargout,%nargin]=argn(0);

if %nargin==1 then, DSCHWELLE=0; end		// set distance criteria

csinfo=csanaly(cs);			        		// simple information about vector data
zinfo=size(csinfo,1);						// number of vectors

ki=1:1:zinfo;				        		// index vector

perc=0; percold=0;
winID=waitbar(perc,'Done');

NEIGHB=[];
for k=1:1:zinfo,
	perc=round(50*k/zinfo);				// wait bar update
	if perc>percold+1,
		waitbar(perc/100,winID);
		percold=perc;
	end
	ksel=ki(ki==k);
	krest=ki(ki~=k);
	d1a=abs(csinfo(krest,9) - csinfo(ksel,9));
	d1b=abs(csinfo(krest,9) - csinfo(ksel,10));
	d2a=abs(csinfo(krest,10) - csinfo(ksel,9));
	d2b=abs(csinfo(krest,10) - csinfo(ksel,10));
	dma=[d1a,d2a]; dmb=[d1b,d2b];
	NBH=[sum(dma<=DSCHWELLE),sum(dmb<=DSCHWELLE)];
	NEIGHB=[NEIGHB;NBH];
end

csinfo=[csinfo,NEIGHB];			// vector info is completed with
					            // number of neighbours
					            // vectors with one neighbour
					            // are start vectors.

					            // Maximum number of neighbours
wtmp=real(csinfo(:,11:12));
nbhmx=max(wtmp);

NBHMATRIX1=zeros(zinfo,nbhmx);	// create neighbour matrices
NBHMATRIX2=zeros(zinfo,nbhmx);

ki=1:1:zinfo;
for k=1:1:zinfo,
	perc=round(50 + 50*k/zinfo);	// update waitbar
	if perc>percold+1,
		percold=perc;
		waitbar(perc/100,winID);
	end
	ksel=ki(ki==k);
	krest=ki(ki~=k);

	d1a=abs(csinfo(krest,9) - csinfo(ksel,9));
	k1a=mtlb_find(d1a<=DSCHWELLE); k1a=krest(k1a);

	d1b=abs(csinfo(krest,9) - csinfo(ksel,10));
	k1b=mtlb_find(d1b<=DSCHWELLE); k1b=krest(k1b);

	d2a=abs(csinfo(krest,10) - csinfo(ksel,9));
	k2a=mtlb_find(d2a<=DSCHWELLE); k2a=krest(k2a);

	d2b=abs(csinfo(krest,10) - csinfo(ksel,10));
	k2b=mtlb_find(d2b<=DSCHWELLE); k2b=krest(k2b);
	kfia=[]; kfib=[];
	kfia=mtlb_sort([k1a(:);k2a(:)]).';
	kfib=mtlb_sort([k1b(:);k2b(:)]).';

	if ~isempty(kfia),
		NBHMATRIX1(k,1:1:length(kfia))=kfia;
	end
	if ~isempty(kfib),
		NBHMATRIX2(k,1:1:length(kfib))=kfib;
	end
end
winclose(winID);

csinfo=[csinfo,NBHMATRIX1,NBHMATRIX2];

if %nargout==2 then
	pkpu=csinfo(:,10);
	csinfo=csinfo(:,9);
end

endfunction