function [y] = dec2bin(x,y) 
// DEC2BIN
//    conversion of decimal numbers into binary representation
// 
//          Y=DEC2BIN(X,Y): X = Scalar (recursive calculation)
//    or    Y=DEC2BIN(X)  : X = Row vector (iterative calc.)             
// 
//  X=Scalar: The binary representation is contained in the vector. The 1st element is the lsb (least significant bit)
//
//  X=Row vector: The binary representations of the decimal numbers in X are contained in a matrix Y. Each column of Y
//      represents the corresponding value of X. The 1st row of Y contains the msb's (most significant bit), the last
//      row of Y contains the lsb's. 

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==2 then
  // Einzelne Zahl - Rekursive Umwandlung
  if mtlb_logic(mtlb_double(x),">=",1) then
    // !! L.19: Matlab function nextpow2 not yet converted, original calling sequence used
    N = mtlb_s(mtlb_double(nextpow2(mtlb_a(mtlb_double(x),0.0001))),1);
    y(1,mtlb_a(N,1)) = 1;
    x = mtlb_s(mtlb_double(x),2^N);
    if mtlb_logic(abs(mtlb_double(x)),">=",0.2) then
      // !! L.23: Matlab function dec2bin not yet converted, original calling sequence used
      y = dec2bin(x,y);
    end;
  end;
else
  // Vektor- Iterative Umwandlung
  %v01_2 = mtlb_double(x);
  %v11_2 = mtlb_double(mtlb_max(%v01_2,firstnonsingleton(%v01_2)));
  maxx = mtlb_max(%v11_2,firstnonsingleton(%v11_2));
  %v21_2 = mtlb_double(x);
  %v31_2 = mtlb_double(mtlb_min(%v21_2,firstnonsingleton(%v21_2)));
  minx = mtlb_min(%v31_2,firstnonsingleton(%v31_2));
  if mtlb_logic(mtlb_double(minx),"<",0) then
    disp("Wertebereichsfehler !!!");
    return;
  end;
  basis = ceil(log(mtlb_a(mtlb_double(maxx),0.0001))/log(2));
  xk = x;
  y = [];
  for k = mtlb_imp(mtlb_s(basis,1),-1,0)
    xtmp = floor(mtlb_double(xk) ./(2^k));
    y = [y;xtmp];
    xk = mtlb_s(mtlb_double(xk),(2^k)*xtmp);
  end;
end;
// Prozedurende
endfunction
