function [MP,R,v,tri]=delaunay(u,tf)
// DELAUNAY	Delaunay-Triangulation
//
//		[MP,R,ZLIS,TRI]=DELAUNAY(Z) or
//		TRI=DELAUNAY(Z)
//
//		when the function is called only with one output
//		argument, the delaunay triangulation is shown in
//		a graphical window.
//
//		Z	:	points specified by complex vector
//		MP	:	Delaunay points, given by complex vector
//		R	:	hullcircle-Radius of Delaunay points
//		ZLIS:	Matrix with points belonging to a triangle.
//				The command "PLOT2D(REAL(ZLIST),IMAG(ZLIST))"
//				draws the result of triangulation
//		TRI	:	Matrix with Indices of the points contained in Z.
//				Each row describes a triangle.
//
//		This function is more or less for learning tasks. A better
//		way is using mesh2d from the great "MetaNet"-Toolbox.
//		This function has problems with regular distributed points,
//		it works fine with points of random distribution.

[%nargout,%nargin]=argn(0);
if %nargin==1 then,
	tf=1E-4;
end

LU=length(u);
ki=1:1:LU;

v=[];
tri=[];
MP=[];
R=[];

winID=waitbar(0,'Delaunay Triangulation');
perc=0; percold=0;

for k1=1:1:LU-2,
	for k2=k1+1:LU-1,
		countctrl=0;
		for k3=k2+1:LU,

			krest=ki(ki~=k1);
			krest=krest(krest~=k2);
			krest=krest(krest~=k3);
			urest=u(krest);

			vakt=[u(k1),u(k2),u(k3)];
			vmat=[real(vakt(:)),imag(vakt(:))];
			[mp,r]=ponci(vmat);
			if ~isempty(mp),
				mp=mp(1) + %i .*mp(2);

				drest=abs(urest-mp);
				if ~or( (drest-r)<(-tf) ),
					v=[v;vakt];
					triakt=[k1,k2,k3];
					tri=[tri;triakt];
					MP=[MP;mp];
					R=[R;r];
					countctrl=countctrl+1;
				end
			end
		if countctrl==2, break; end
		end
	end
	perc=round(100 .*k1 ./(LU-2));
	if perc>=percold+1,
		waitbar(perc/100,winID);
		percold=perc;
	end
end
winclose(winID);

v=[v,v(:,1)].';

if %nargout<=1 then,
	plot2d(real(v),imag(v),style=2*ones(1,size(v,2)));
	plot2d(real(u),imag(u),style=-3);
	MP=tri;	
end
endfunction