function y=dither(x,method);
// DITHER	Ordered-Dithering of a  GrayScale matrix
//
//		Y=DITHER(X,[METHOD])
//
//		X	: GrayScale-Matrix {1..256}
//		METHOD	: 'b1' -> Ordered Dither (Bayer-1)
//			  'b2' ->   "       "    (Bayer-2)
//			  'b3' ->   "       "    (Bayer-3)
//			  's1' ->   "       "    (Stucki-1)
//			  's2' ->   "       "    (Stucki-2)
//			  'rd' -> Random-Dither-Matrix
//			  'rand' -> Random-Dithering  (default)
//		Y	: dithered binary picture

[%nargout,%nargin]=argn(0);

if %nargin==1,						          // Argument METHOD ist
	method='random';				        // optional. Voreinstellung
end							               // ist Random-Dithering
method=mtlb_lower(part(method,1:2));
[zx,sx]=size(x);					        // Gre des Bildes

							              // Masken-Definitionen
msk0=[0,2;3,1];						        // Bayer-1    -> 'b1'
msk1=[4*msk0,4*msk0+2;4*msk0+3,4*msk0+1];	// Bayer-2    -> 'b2'
msk2=[4*msk1,4*msk1+2;4*msk1+3,4*msk1+1];	// Bayer-3    -> 'b3'
											// Stucki-1   -> 's1'
msk3=[22,6,18,2,21,5,17,1;				
      14,30,10,26,13,29,9,25;
      20,4,24,8,19,3,23,7;
      12,28,16,32,11,27,15,31;
      21,5,17,1,22,6,18,2;
      13,29,9,25,14,30,10,26;
      19,3,23,7,20,4,24,8;
      11,27,15,31,12,28,16,32];
											// Stucki-2  -> 's2'  
msk4=[19,25,23,17,14,8,10,16;
      21,31,29,27,12,2,4,6;
      28,30,32,22,5,3,1,11;
      18,24,26,20,15,9,7,13;
      14,8,10,16,19,25,23,17;
      12,2,4,6,21,31,29,27;
      5,3,1,11,28,30,32,22;
      15,9,7,13,18,24,26,20];
msk6=randvek(64);
msk6=matrix(msk6,8,8);						// Random-Dither-Matrix

if method~='ra',					        // Dither-Maskierung
	if method=='b1',
		maske=msk0;
		maske=(1+maske) .*63;
	end
	if method=='b2',
		maske=msk1;
		maske=(1+maske) .*15;
	end
	if method=='b3',
		maske=msk2;
		maske=(1 + maske) .*4;
	end
	if method=='s1',
		maske=msk3;
		maske=maske .*8;
	end
	if method=='s2',
		maske=msk4;
		maske=maske .*8;
	end
	if method=='rd',
		maske=(msk6-1) .*4;
	end

	[zm,sm]=size(maske);

	[pz,ps,pv]=mtlb_find(x);
	pzred=1 + modulo(pz,zm);				// Positionen innerhalb der
	psred=1 + modulo(ps,sm);				// Dither-Maske

	maske=maske(:);
	elem=(psred - 1) .*zm + pzred;
	pvschw=maske(elem);
	pvneu=bool2s(pv>pvschw);				    		      // Maskenwerte mit Bildwerten
	y=sparse([pz(:),ps(:)],pvneu,[zx,sx]);		// vergleichen -> Bildaufbau
else
	y=zeros(zx,sx);					 // Zufallssbilder (2) mit
	for k=1:1:2,					    // Grauwert-Bild vergleichen
		randpic=ceil(256 .*rand(zx,sx));
		y=y + (x>=randpic);
	end
	y=bool2s(y>=1);
end

endfunction
