function [f] = factor(n)
//FACTOR Prime factors.
//   FACTOR(N) returns a vector containing the prime factors of N.
// 
//   This function uses the simple sieve approach. It may require large
//   memory allocation if the number given is too big. Technically
//   it is possible to improve this algorithm, allocating less
//   memory for most cases and resulting in a faster execution
//   time. However, it will still have problems in the worst
//   case, so we choose to impose an upper bound on the input number
//   and error out for n > 2^64. 

// Ouput variables initialisation (not found in input variables)
f=[];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if prod(size(mtlb_double(n)))~=1 then
  error("N must be a scalar.");
end;
if bool2s(mtlb_logic(mtlb_double(n),"<",0))|bool2s(mtlb_logic(floor(mtlb_double(n)),"~=",mtlb_double(n))) then
  error("N must be a positive integer.");
end;
if mtlb_logic(mtlb_double(n),">",2^64) then
  error("The maximum value of n allowed is 2^64 .");
end;

if mtlb_logic(mtlb_double(n),"<",4) then
  f = n;
  return;
else
  f = [];
end;

p = primes(sqrt(mtlb_double(n)));
while mtlb_logic(mtlb_double(n),">",1)
  d = mtlb_find(bool2s(mtlb_logic(mtlb_double(n)-fix(mtlb_double(n) ./p) .*p,"==",0)));
  if isempty(d) then
    f = [f,n];
    break;
  end;
  p = p(d);
  f = [f,p];
  n = mtlb_double(n)/prod(p,firstnonsingleton(p));
end;

f = mtlb_sort(f);
endfunction
