function [FEIERTAGNAME,Qfeier,WOTA]=feiertag(j,bdg,kath)
// FEIERTAG	calculation of celebration days
//
//		[Feiertag,Datum]=feiertag(jahr,bundesland,katholisch)
//
//		Bedeutung der Variablen:
//		Feiertag	:	String-Array with names of celebration days
//		Datum		:	Matrix with 3 columns [day, month, year].
//						The rows of this matrix and the string array
//						"Feiertag" are belonging together
//		Wochentag	:	The week day of the celebration day
//		Jahr		:	Scalar, represents the year
//		Bundesland	:	String with 3 chars, labelling the german countries.
//		(optional)		Meaning of the abbreveations...
// 						BAY	Bayern
// 						BRB	Brandenburg
// 						BAW	Baden-Wrttemberg
// 						HES	Hessen
// 						MVP	Mecklenburg-Vorpommern
// 						NRW	Nordrhein-Westfalen
// 						RPF	Rheinland-Pfalz
// 						SAC	Sachsen
// 						SAA	Sachsen-Anhalt
// 						SAR	Saarland
// 						TH	Thringen
//		katholisch	:	Booleane Variable {0,1}. In some countries
//		(optional)		only in catholic regions there is a celeb. day.

[%nargout,%nargin]=argn(0);

if %nargin==1 then,
	bdg='all';
	kath=0;
end
if %nargin==2 then,
	kath=0;
end

FEIERTAGNAME=['Neujahr';'Hl. 3 Knige';'Karfreitag';'Ostersonntag';'Ostermontag'];
FEIERTAGNAME=[FEIERTAGNAME;'Maifeiertag';'Christi Himmelf.';'Pfingstsonntag';...
		'Pfingstmontag';'Trinitatis';'Fronleichnam';'Maria Himmelf.'];
FEIERTAGNAME=[FEIERTAGNAME;'Tag der Einheit';'Reformationstag';'Allerheiligen';...
		'Volkstrauertag';'Bu- und Bettag';'Totensonntag';'Heilig Abend';...
		'1. Weihnachtsfeiertag';'2. Weihnachtsfeiertag';'Silvester'];

m=zeros(1,12);						// Berechnung der Monatstage
for k=1:1:11, m(k)=dday([1,k,j;1,k+1,j]); end
m(12)=31;

[Q,os]=ostern(j);

neujahr=0;
hl3k=5;
karfreitag=os-2;
maifeiertag=sum(m(1:4));
chrhimmel=os+39;
pfingstsonntag=os+49;
pfingstmontag=os+50;
trinitatis=pfingstsonntag+7;
fronleichnam=trinitatis+4;
mariahimmel=sum(m(1:7))+14;
einheit=sum(m(1:9))+2;
reformation=sum(m(1:10))-1;
allerheiligen=reformation+1;
weihn1=sum(m(1:11))+24;
weihn2=weihn1+1;
weihn0=weihn1-1;
advent1=weihn1-21;

w0tmp=calcdat([1,1,j],advent1);
dayadvent=date2day(w0tmp($:-1:1));
while mtlb_any(str2code(mtlb_lower(part(dayadvent,1:2)))~=str2code(mtlb_lower('Su'))),
	advent1=advent1-1;
	w0tmp=calcdat([1,1,j],advent1);
	dayadvent=date2day(w0tmp($:-1:1));
end

volkstrauer=advent1-14;
totensonn=advent1-7;
bustag=totensonn-4;

silvester=sum(m(1:12))-1;

diffdays=[neujahr,hl3k,karfreitag,os,os+1,maifeiertag,chrhimmel,...
	pfingstsonntag,pfingstmontag,trinitatis,fronleichnam,...
	mariahimmel,einheit,reformation,allerheiligen,volkstrauer,...
	bustag,totensonn,weihn0,weihn1,weihn2,silvester].';
Qfeier=calcdat([1,1,j],diffdays(:));

WOTA='Wochentag';
for p=1:1:size(Qfeier,1),
	Qakt=Qfeier(p,$:-1:1);
	woakt=date2day(Qakt);
	WOTA=[WOTA;woakt];
end
WOTA=WOTA(2:1:$);

if mtlb_any(str2code(bdg)~=str2code('all')),
	select=[1,3,4,5,6,7,8,9,13,16:1:22];
													// hl. 3 Knige ist in diesen
	if (bdg=='baw' | bdg=='bay' | bdg=='saa'),		// Bundeslndern gesetzlicher
		select=[select,2];							// Feiertag
	end
													// Fronleichnam ist in diesen
													// Bundeslndern gesetzlicher
													// Feiertag
	if (bdg=='baw' | bdg=='bay' | bdg=='hes' | bdg=='nrw' | bdg=='rpf' | bdg=='sar'),
		select=[select,11];
	end
								// Fronleichnam wird in
	if (bdg=='sac' | bdg=='th') & kath==1,			// Sachsen und Thringen nur
		select=[select,11];				// in katholischen Gebieten
	end							// gefeiert.

	if (bdg=='bay' & kath==1) | bdg=='sar',			// Maria Himmelfahrt ist im
		select=[select,12];				// saarland gesetzlich, in Bayern
	end							// wird nur in kath. Gebieten
								// gefeiert.

								// In diesen Bundeslndern ist
								// der Reformationstag gesetzl.
	if (bdg=='brb' | bdg=='mvp' | bdg=='sac' | bdg=='saa' | bdg=='th'),
		select=[select,14];
	end
								// Allerheiligen ist in diesen
								// Lndern gesetzlich
	if (bdg=='baw' | bdg=='bay' | bdg=='nrw' | bdg=='rpf' | bdg=='sar'),
		select=[select,15];
	end
	select=sort(select);
	FEIERTAGNAME=FEIERTAGNAME(select,:);
	Qfeier=Qfeier(select,:);
	WOTA=WOTA(select);
end