function [K] = findgrup(a,modus) 
//FINDGRUP
//		K=FINDGRUP(A,[MODUS])
//
//		from the binary vector A the starting- and endpositions
//		of groups with 1 are determined.
//		If the optional argument MODUS (default=0) is not used, the first
//		and last group is neglected.
// 
//		Example:
//		(1):	a=[1,1,1,0,0,0,1,1,0,0,0,1,1,1];
//				ki=findgrup(a);
// 
//				ki=[7;8]
// 
//		(2):	ki=findgrup(a,1)
// 
//				ki=[1, 7,12;
//     				3, 8,14]

// Ouput variables initialisation (not found in input variables)
K=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==1 then
  modus = 0;
end;

a = mtlb_0(mtlb_e(a,:));

if mtlb_logic(mtlb_double(modus),"~=",0) then
  a = [0,a,0];
end;

if bool2s(isempty(mtlb_find(abs(mtlb_double(a)))))|bool2s(isempty(mtlb_find(bool2s(~mtlb_double(a))))) then
  K = [];
  return;
end;

d = diff(mtlb_double(a),1,firstnonsingleton(mtlb_double(a)));

kmin = mtlb_a(mtlb_find(bool2s(mtlb_logic(d,">",0))),1);
kmin = kmin(:);
kmax = mtlb_a(mtlb_find(bool2s(mtlb_logic(d,"<",0))),1);
kmax = mtlb_s(kmax,1);
kmax = kmax(:);

if mtlb_logic(mtlb_double(mtlb_e(a,1)),"==",1) then
  kmax = kmax(2:max(size(kmax)));
end;
if mtlb_logic(mtlb_double(mtlb_e(a,max(size(mtlb_double(a))))),"==",1) then
  kmin = kmin(1:max(size(kmin))-1);
end;
K = [kmin,kmax].';
if mtlb_logic(mtlb_double(modus),"~=",0) then
  K = K-1;
end;
// ENDE
endfunction
