function K=fresnel(x)
// FRESNEL
//		K=FRESNEL(X);
//		calculation of the fresnel integrals
//			K(x)=C(x) + i*S(x)
//		calculation is not done by integration
//		but by evaluation of approximations
//		and series.
//		(taken from Abramowitz / Stegun)

pi=%pi;

[zx,sx]=size(x);
vz=sign(x);
x=abs(x);

xmin=1.4;
xmax=200;

[z0,s0,xw0]=mtlb_find(x .*(x<=1E-6));					          // -> Lineare Nherung
[z1,s1,xw1]=mtlb_find(x .*((x<=xmin) & (x>1E-6)));		// -> Taylor-Serie
[z2,s2,xw2]=mtlb_find(x .*((x>xmin)&(x<=xmax)));		  // -> Kettenbruch-Evaluierung
[z3,s3,xw3]=mtlb_find(x .*(x>xmax) );					          // -> Nherungsformel

if ~isempty(xw0),						                             // Lineare Nherung
	K0=xw0 + %i .*zeros(xw0);
else
	K0=[];
end

if ~isempty(xw1),						// Taylor-Reihe
	sm=0;
	sums=zeros(xw1);
	sumc=xw1;
	fact=(%pi ./2) .*(xw1 .^2);
	term=xw1;
	sgn=1;
	odd=1;
	n=3;
	for k=1:65,
		term=term .*fact ./k;
		sm=sm + sgn .*term ./n;
		if odd==1,
			sgn=-sgn;
			sums=sm;
			sm=sumc;
		else
			sumc=sm;
			sm=sums;
		end
		odd=-odd;
		n=n+2;	
	end
	K1=sumc + %i .*sums;
else
	K1=[];
end

if ~isempty(xw2),						           // Evaluating Continued
	i=sqrt(-1);						               // Fraction by Lentz's
	z=0.5*sqrt(%pi)*(1-%i) .*xw2;			// Method
	qn=2 .*z .*z + 1;
	tw=zeros(xw2);
	for k=61:-2:1,
		fak=-k .*(k+1);
		addo=(k+1) .*2;
		tw=fak ./(qn + addo + tw);
	end

	tw=1 ./(qn+tw);
	tw=2 .*z .*tw ./sqrt(%pi);
	tw=tw .*exp(-(z .^2));
	tw=1 - tw;
	K2=0.5 .*(1 + %i) .*tw;
else
	K2=[];
end

if ~isempty(xw3),						// Evaluierung der Nherung
	i=sqrt(-1);
	K3=0.5 .*(1+%i) - %i .*exp(%i .*0.5 .*%pi .*xw3 .*xw3) ./(%pi .*xw3);
else
	K3=[];
end

K=zeros(zx,sx)+full(sparse([z0(:),s0(:)],K0,[zx,sx]));// Gesamtkomposition
K=K+full(sparse([z1(:),s1(:)],K1,[zx,sx]));
K=K+full(sparse([z2(:),s2(:)],K2,[zx,sx]));
K=K+full(sparse([z3(:),s3(:)],K3,[zx,sx]));
K=K .*vz;							// Vorzeichenbercksichtigung

endfunction;
