function [Q,CC]=gaussfit(x,y);
// GAUSSFIT		optimal gauss curve through given data set
//
//		[Q,CC]=GAUSSFIT(X,Y);
//
//		The data set {x(k),y(k)} should be approximated by an optimal Gauss curve
//		of the form
//						y=k0*exp(-(x-)^2 / 2*s^2)
//
//		The quadratic deviations are optimized. Base of optimization is the equation
//				exp(b2*x^2 + b1*x + b0).
//
//		CC represents the approximation quality 0<=CC<=1, the matrix Q contains in
//		the 1st row the coefficients b2,b1,b0 and in the 2nd row the parameters.
//		k0, , Sigma of the optimal gauss curve.
//
//		Only data points with y>0 are used for approximation.

[%nargout, %nargin]=argn(0);
if %nargin==1,
	y=x;
	x=linspace(-1,1,length(y));
end

x=x(:); y=y(:);
x=x(y>0);y=y(y>0);

[x,kxs]=gsort(x);
y=y(kxs);
N=length(x);

// Coefficients of exponential polynom
A=[N,sum(x),sum(x .^2);sum(x),sum(x .^2),sum(x .^3);sum(x .^2),sum(x .^3),sum(x .^4)];
b=[sum(log(y));sum(x .*log(y));sum((x .^2) .*log(y))];
c=inv(A)*b;

// conversion into mean, stddev and factor
b2=c(3);b1=c(2);b0=c(1);
k0=exp(b2*((b0/b2)-(0.5*b1/b2)^2));
mueh=-0.5*b1/b2;
sigma=sqrt(-1/(2*b2));
Q=[c(3),c(2),c(1);k0,mueh,sigma];

// correlation coefficient
xm=(x - mueh) .^2;
ym=-2 .*(sigma .^2) .*log(y ./k0);
CC=corrcoeff(xm,ym);

// graphical output
subplot(121);
	yk=k0 .*exp(-((x-mueh) .^2) ./(2 .*(sigma .^2)));
	plot2d(x(:),[y(:),yk(:)],style=[-2,1],logflag="nn");
	xtitle('cartesian grid',"X","Y");

subplot(122);
	aq=regress(xm,ym);
	yml=aq(2) .*xm + aq(1);
	plot2d(xm(:),[ym(:),yml(:)],style=[-4,1]);
	titstr='Gauss paper: r = ' + mtlb_num2str(CC*100) + ' %';
	xtitle(titstr,"(X-)^2","-2*(s^2)*log(Y/k0)");

endfunction