function [z] = geo2gkk(w2,w1)
//GEO2GKK  conversion geograph. coordinates -> UTM-coord.
// 
//Z=GEO2GKK(W1,W2)
//conv. of Geo. coordinates into Gau-Krger coordinates
//W1: Vector with longitude (DEG)
//W2: Vector with lattitude (DEG)
//Z : complex Vector with Gau-Krger coord.
//    Real part=right value, Imag. part=height value
//international GKK coordinates are assumed.


// Ouput variables initialisation (not found in input variables)
z=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==1 then
  w1 = w2(:,2);
  w2 = w2(:,1);
end;

w1 = (%pi .*mtlb_double(w1)) ./180;     // Umrechnung DEG->RAD
w2 = (%pi .*mtlb_double(w2)) ./180;
A = 6377397.15508;                      // Konstanten des
B = 6356078.9629;                       // Erdellipsoids (deutsches LVMA)

//B=A-(A/297);% (international)

//A=6378137;                             % WGS84
//B=6356752.314;

EF = sqrt(1-(B/A)^2);
M0 = (B^2)/A;
itmax = 60;

// Anfangswerte
// -----------------------------------------------------
// !! L.38: If sin(w1) is outside [-1,1]
// !!    complex part of output of atanh(sin(w1)) will be the opposite of Matlab one.
// !! L.38: If EF .*sin(w1) is outside [-1,1]
// !!    complex part of output of atanh(EF .*sin(w1)) will be the opposite of Matlab one.
wc = mtlb_a(mtlb_s(atanh(sin(w1)),EF .*atanh(EF .*sin(w1))),%i .*w2);
b = zeros(max(size(w1)),itmax+1);
// !! L.39: If tanh(wc) is outside [-1,1]
// !!    complex part of output of asin(tanh(wc)) will be the opposite of Matlab one.
b(:,1) = asin(tanh(wc));
d = zeros(max(size(w1)),itmax+1);
d(:,1) = ones(max(size(w1)),1);
K = d;
ztold = zeros(max(size(w1)),1);
ztold = ztold+%i .*ztold;
flaggy = 0;
ki = 0;
// -------------------------------------------------------

while bool2s(flaggy==0)&bool2s(ki<itmax)
  ki = ki+1;
  fi1 = ((2 .*(ki-1)+1) .*(2 .*(ki-1)+3)) ./((2 .*(ki-1)+2) .^2);
  d(:,ki+1) = ((fi1*d(:,ki)) .*EF) .*EF;
  D = mtlb_sum(d.').';
  D = mtlb_s(D,1);
  fi2 = (2 .*(ki-1)+2) ./(2 .*(ki-1)+3);
  K(:,ki+1) = fi2*K(:,ki);
  DS = zeros(max(size(w1)),1);
  for kz = 1:1:ki
    SK = zeros(max(size(w1)),1);
    for L = 0:1:kz-1
      SK = SK+K(:,L+1) .*(sin(b(:,ki)) .^(2*L));
    end;
    DS = DS+d(:,kz+1) .*SK;
  end;
  // !! L.61: If EF .*sin(b(:,ki)) is outside [-1,1]
  // !!    complex part of output of atanh(EF .*sin(b(:,ki))) will be the opposite of Matlab one.
  // !! L.61: If tanh(mtlb_a(wc,EF .*atanh(EF .*sin(b(:,ki))))) is outside [-1,1]
  // !!    complex part of output of asin(tanh(mtlb_a(wc,EF .*atanh(EF .*sin(b(:,ki)))))) will be the opposite of Matlab one.
  b(:,ki+1) = asin(tanh(mtlb_a(wc,EF .*atanh(EF .*sin(b(:,ki))))));
  z = (M0 .*mtlb_a(1,D)) .*b(:,ki+1)-((0.5 .*M0) .*DS) .*sin(2 .*b(:,ki+1));
  ztneu = z;
  %v02_1 = abs(mtlb_s(ztneu,ztold));
  if mtlb_logic(max(%v02_1,firstnonsingleton(%v02_1)),"<",0.00001) then flaggy = 1;end;
  ztold = ztneu;
end;
z = mtlb_a(imag(z),%i .*real(z));
// Prozedurende
endfunction
