function [z,NR] = geo2gkn(w2,w1,NR)
//GEO2GKN  conversion of geographical coord. into GK-N coordinates
// 
//[Z,NR]=GEO2GKN(W1,W2,[NR])
//
//W1: Vector with longitude values (DEG)
//W2: Vector with lattitude values (DEG)
//Z : complex vector with Gauss-Krger coordinates.
//    Real part = Right Value, Imag. part = height value
//GK-coordinates related to a reference meridional stripe. This stripe has the number NR.
//NR is optional. It's default value is calculated in relation to the longitude.

z=[];  // Ouput variables initialisation (not found in input variables)

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==1 then
  w1 = w2(:,2);
  w2 = w2(:,1);
end;
if %nargin==3 then        // Meridianstreifennr.
  NR = NR .*ones(size(w1,1),size(w1,2));
else
  NR = round((w2+1.5) ./3);
end;
L0 = NR .*3;              // Mittelmeridian

z = geo2gkk(w2-L0,w1);
z=(real(z) + (NR .*1E6) + 5E5) + %i .*imag(z);
endfunction