function [lam,phi] = gkk2geo(Z) 
//GKK2GEO  UTM-Coordinates -> geograph. Coord.
// 
//[W1,W2]=GKK2GEO(Z)
//conversion of Gauss-Krger-coordinates
//into geographical coordinaten by Klotz (1993)
//W1: Vector with longitudes (DEG)
//W2: Vector with lattitude (DEG)
//Z : complex Vector with Gau-Krger-coord.
//    Real part=Right value, Imag. part=Height value


// Ouput variables initialisation (not found in input variables)
lam=[];
phi=[];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);



A = 6377397.15508;        // Konstanten des
B = 6356078.9629;         // Erdellipsoids (deutsches LVMA)
                          //B=A-(A/297);% (international)
EF = sqrt(1-(B/A)^2);
M0 = (B^2)/A;
itmax = 60;

// Anfangswerte
// -----------------------------------------------------
b = zeros(max(size(mtlb_double(Z))),itmax+1);
b(:,1) = mtlb_double(Z) ./M0;
d = zeros(max(size(mtlb_double(Z))),itmax+1);
d(:,1) = ones(max(size(mtlb_double(Z))),1);
K = d;
w2 = zeros(max(size(mtlb_double(Z))),1);
w1 = w2;
lamv = zeros(max(size(mtlb_double(Z))),1);
phiv = zeros(max(size(mtlb_double(Z))),1);
flaggy = 0;
ki = 0;
// -------------------------------------------------------
Z = conj(-%i .*mtlb_double(Z));

while bool2s(flaggy==0)&bool2s(ki<itmax)
  ki = ki+1;
  fi1 = ((2 .*(ki-1)+1) .*(2 .*(ki-1)+3)) ./((2 .*(ki-1)+2) .^2);
  d(:,ki+1) = ((fi1*d(:,ki)) .*EF) .*EF;
  D = mtlb_sum(d.').';
  D = mtlb_s(D,1);
  fi2 = (2 .*(ki-1)+2) ./(2 .*(ki-1)+3);
  K(:,ki+1) = fi2*K(:,ki);
  DS = zeros(max(size(w1)),1);
  for kz = 1:1:ki
    SK = zeros(max(size(Z)),1);
    for L = 0:1:kz-1
      SK = SK+K(:,L+1) .*(sin(b(:,ki)) .^(2*L));
    end;
    DS = DS+d(:,kz+1) .*SK;
  end;
  b(:,ki+1) = mtlb_a(Z ./M0,(0.5 .*sin(2 .*b(:,ki))) .*DS) ./mtlb_a(1,D);
  // !! L.52: If sin(b(:,ki+1)) is outside [-1,1]
  // !!    complex part of output of atanh(sin(b(:,ki+1))) will be the opposite of Matlab one.
  // !! L.52: If EF .*sin(b(:,ki+1)) is outside [-1,1]
  // !!    complex part of output of atanh(EF .*sin(b(:,ki+1))) will be the opposite of Matlab one.
  wc = atanh(sin(b(:,ki+1)))-EF .*atanh(EF .*sin(b(:,ki+1)));
  phi = real(wc);
  q = phi;
  deltaphi = 1000;
  while deltaphi>0.000000000001
    phin = phi;
    // !! L.58: If EF .*sin(phi) is outside [-1,1]
    // !!    complex part of output of atanh(EF .*sin(phi)) will be the opposite of Matlab one.
    // !! L.58: If tanh(mtlb_a(q,EF .*atanh(EF .*sin(phi)))) is outside [-1,1]
    // !!    complex part of output of asin(tanh(mtlb_a(q,EF .*atanh(EF .*sin(phi))))) will be the opposite of Matlab one.
    phi = asin(tanh(mtlb_a(q,EF .*atanh(EF .*sin(phi)))));
    %v02_1 = abs(mtlb_s(phin,phi));  deltaphi = max(%v02_1,firstnonsingleton(%v02_1));
  end;
  lam = imag(wc);
  %v11_1 = abs(mtlb_s(lam,lamv));
  deltalam = max(%v11_1,firstnonsingleton(%v11_1));
  if bool2s(mtlb_logic(deltalam,"<",0.000000000001))&bool2s(mtlb_logic(deltaphi,"<",0.000000000001)) then
    flaggy = 1;
  end;
  lamv = lam;
  phiv = phi;
end;
phi = (phi .*360)/(2*%pi);
lam = (lam .*360)/(2*%pi);
endfunction
