function [fx,fy]=grad(F,dx,dy);
//GRAD  gradient of function F
//
//      [fx,fy]=grad(F)     ->  dx and dy are assumed as 1
//      [fx,fy]=grad(F,dx)  ->  dy is same as dx
//      [fx,fy]=grad(F,x,y) ->  x and y are vectors, defining the grid


fx=[];
fy=[];

[%nargout,%nargin]=argn(0);

if %nargin<1 | %nargin>3 then
  disp('Wrong no. of input arguments in function grad...');
  return;
end

if %nargin==1 then,
  dx=1;
  dy=1;
end
if %nargin==2 then,
  if size(dx)==[1,1] then
    dy=dx;
  else
    error('When 2nd rhs-argument is not a scalar, you must have a 3rd rhs-argument!');
    return;
  end
end

fx=zeros(F);
fy=zeros(F);

if isvector(dx) & isvector(dy) then
  [DX,DY]=meshgrid(dx,dy);
end

if size(dx)==[1,1] then
  fx(:,2:1:$-1)=(-F(:,1:1:$-2) + F(:,3:1:$)) ./(2 .*dx);
  fx(:,1)=(-F(:,1) + F(:,2)) ./(dx);
  fx(:,$)=(-F(:,$-1) + F(:,$)) ./(dx);
end

if isvector(dx) then
  fx(:,2:1:$-1)=(-F(:,1:1:$-2) + F(:,3:1:$)) ./(DX(:,3:1:$) - DX(:,1:1:$-2));
  fx(:,1)=(-F(:,1) + F(:,2)) ./(DX(:,2)-DX(:,1));
  fx(:,$)=(-F(:,$-1) + F(:,$)) ./(DX(:,$)-DX(:,$-1));
end


if size(dy)==[1,1] then
  fy(2:1:$-1,:)=(-F(1:1:$-2,:) + F(3:1:$,:)) ./(2 .*dy);
  fy(1,:)=(-F(1,:) + F(2,:)) ./dy;
  fy($,:)=(-F($-1,:)+F($,:)) ./dy;
end

if isvector(dy) then
  fy(2:1:$-1,:)=(-F(1:1:$-2,:) + F(3:1:$,:)) ./(DY(3:1:$,:) - DY(1:1:$-2,:));
  fy(1,:)=(-F(1,:) + F(2,:)) ./(DY(2,:)-DY(1,:));
  fy($,:)=(-F($-1,:)+F($,:)) ./(DY($,:)-DY($-1,:));
end

endfunction
