function y=mtlb_filter(B,A,x);
// MTLB_FILTER
//    One-dimensional digital filter.
//    Y = MTLB_FILTER(B,A,X) filters the data in vector X with the
//    filter described by vectors A and B to create the filtered
//    data Y.  The filter is a "Direct Form II Transposed"
//    implementation of the standard difference equation:
//
//    a(1)*y(n) = b(1)*x(n) + b(2)*x(n-1) + ... + b(nb+1)*x(n-nb)
//                          - a(2)*y(n-1) - ... - a(na+1)*y(n-na)
// 
//    If a(1) is not equal to 1, FILTER normalizes the filter
//    coefficients by a(1).

x=x(:).';
B=B(:).';
A=A(:).';
Ak1=A(1);
A=A ./Ak1;
LX=length(x);
LB=length(B);
LA=length(A);
y=zeros(x);

[%nargin,%nargout]=argn(0);

for k=1:1:LX,
  sforw=0;
  sback=0;
  for p1=1:1:LB,
    xpos=k-p1+1;
    if xpos>0 then
      sforw=sforw+B(p1)*x(xpos);
    end
  end
  for p2=2:1:LA,
    ypos=k-p2+1;
    if ypos>0 then
      sback=sback+A(p2)*y(ypos);
    end
  end
  y(k)=sforw-sback;
end
y=y ./Ak1;

endfunction
