function [h,w] = mtlb_freqz(b,a,n,dum)
//mtlb_freqz
//Z-transform digital filter frequency response.  When N is an integer,
//[H,W] = mtlb_freqz(B,A,N) returns the N-point frequency vector W and the
//N-point complex frequency response vector G of the filter B/A:
//                            -1                -nb 
//     jw  B(z)   b(1) + b(2)z + .... + b(nb+1)z
//  H(e) = ---- = ----------------------------
//                            -1                -na
//         A(z)    1   + a(2)z + .... + a(na+1)z
//
//given numerator and denominator coefficients in vectors B and A. The
//frequency response is evaluated at N points equally spaced around the
//upper half of the unit circle. To plot magnitude and phase of a filter:
//          [h,w] = mtlb_freqz(b,a,n);
//          mag = abs(h);  phase = angle(h);
//          semilogy(w,mag), plot(w,phase)
//mtlb_freqz(B,A,N,'whole') uses N points around the whole unit circle.
//mtlb_freqz(B,A,W) returns the frequency response at frequencies designated
//in vector W, normally between 0 and pi. (See LOGSPACE to generate W).

// Ouput variables initialisation (not found in input variables)
h=[];
w=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);


a = mtlb_0(mtlb_e(a,:));
b = mtlb_0(mtlb_e(b,:));
na = max(size(mtlb_double(a)));
nb = max(size(mtlb_double(b)));
nn = max(size(mtlb_double(n)));
s = 2;
if %nargin==4 then
  s = 1;
end;
if nn==1 then
  w = ((((2*%pi)/s)*mtlb_imp(0,mtlb_s(mtlb_double(n),1)))/mtlb_double(n))';
else
  w = n;
  n = nn;
end;
if nn==1 then
  h = (mtlb_fft([b,zeros(1,real(mtlb_s(s*mtlb_double(n),nb)))]) ./mtlb_fft([a,zeros(1,real(mtlb_s(s*mtlb_double(n),na)))])).';
  h = h(mtlb_imp(1,mtlb_double(n)));
else
  //Frequency vector specified.  Use Horner's method of polynomial
  //evaluation at the frequency points and divide the numerator
  //by the denominator.
  a = [a,zeros(1,nb-na)];
  // Make sure a and b have the same length
  b = [b,zeros(1,na-nb)];
  s = exp(sqrt(-1)*mtlb_double(w)); 
  h = mtlb_double(polyval(b,s)) ./mtlb_double(polyval(a,s));
end;
endfunction
