function [a,f]=multireg(X,Y,q,adone);
// MULTIREG
//		Linear Regression for linear combined functions
//
//		[a,f]=multireg(X,Y,Q,ADONE);
//
//		X	: Matrix. Each column represents a variable. The number of rows represents
//			  the amount of statistical samples. Each row represents a Tupel (x1,x2,...xm).
//		Y	: The function values belonging to the tupels (x1,x2,...,xm). Y can be a
//			  column vector or a matrix.
//		Q	: Selektion vector. Specifies the coefficients, which should be calculated.
//		ADONE	: Vector with predefined coefficients. The number of elements of ADONE +
//				  the number of elements of Q must be m !
//
//		The quadratic error of the function below is minimized.
//                                                                    2
//           Sum(y - a  - a *x    - a *x    - a *x    - ... - a *x   )
//            i   i   0    1  1,i    2  2,i    3  3,i          m  m,i
//
//		a is a Vector (or a Matrix, depends on Y) with coefficients
//				[a , a , a ,..., a ]
//				  0   1   2       m
//		Therefore, the solution has m+1 elements.
//		The vector f (or matrix) contains the error of the regression.
//
//		Several possibilities are supported:
//		(1)	: 	Global determination of optimal parameters.
//			  	the complete equation system is solved.
//		(2)	: 	the optimal solution is calculated recursevely. The vector Q
//				specifies the sequence.
//
//				Examples:
//
//				Q=[1,3];
//				the optimal parameters a1 and a3 are calculated, the others are set
//				to zero.
//
//				Q=[1,3]; ADONE=[4.32,-3.21,8.30]
//				the optimal parameters a1 and a3 are calculated, the parameters a2,
//				a4 and a5 are defined with the values in ADONE.

[%nargout, %nargin]=argn(0);
mode(0);
ieee(1);

a=[];
f=[];

if %nargin==1,
	Y=X(:,$);
	X=X(:,1:1:$-1);
end
if %nargin<=2,
	W=[ones(size(X,1),1),X];
	a=pinv(W.'*W)*(W.'*Y);
	f=W*a-Y;
else
	if size(Y,2)>1 then
		error('Selective Solutions only when Y is column vector !');
		a=[]; f=[];
		return;
	else
		W=[ones(size(X,1),1),X];
		if %nargin==3,
			adone=zeros(1,size(X,2)+1);
		end
		p0=1:1:size(X,2)+1;
		p1=[1,q+1];
		[C,xex]=schnitt(p0,p1);				// Positionen im Lsungsvektor,
											// die fr vordef. Werte vor-
											// gesehen sind
		a=zeros(size(X,2)+1,1);
		a(xex)=adone(1:1:length(xex)).';	// Eintragen der def. Werte

		YAKT=Y-(W*a);						// PRIMR-Korrektur

		WS=(W.')*W;
		US=(W.')*YAKT;
		WS=WS(p1,p1);
		US=US(p1);
	
		atmp=inv(WS)*US;
		a(p1)=atmp;
		f=W*a-Y;
	end
end

endfunction