function [N2,N1]=nullpass(x,NKO);
// NULLPASS	counting and estimation of Zero Passes
//
//		[N2,N1]=NULLPASS(X,NKO)
//
//		counting and estimation (based on autocorrelation) of the number of Zero passes
//		of a random process. NKO is the number of values of the autocorrelation function in
//		the positive plane. X my be a matrix or a vector. If X is a Matrix,
//		each row vector is analyzed.
//
//		N2	: estimated number of zero passes
//		N1	: counted zero passes
//		X	: random processes
//		NKO	: number of autocorrelation values

[%nargout,%nargin]=argn(0);
ngt=%nargout;						// counting output arguments

if %nargin==1 then,
	NKO=128;
end

[zz,sz]=size(x);					         // matrix size
if ((zz>1) & (sz==1)) then,   // X is a column vector
	x=x.';
end
[zz,sz]=size(x);
NP=sz;							             // Length of row vectors
N1=[];
N2=[];

for k=1:zz,
	if ngt~=1,
		// counting
		// --------
		dxfs=diff(sign(x(k,:)),1);			// Hard-Limiter
		n1=length(find(dxfs~=0));			// Anzahl der Null-Durchgnge
		N1=[N1;n1];							// (bestimmt durch Zhlung)
	end

	// Schtzung
	// ---------
	r=akfrader(x(k,:),NKO);						// Erwartungswert der Anzahl
	r=[r($:-1:1),r(2:NKO)];						// der Nulldurchgnge wird ermittelt
	RXX0=r(NKO);								// Siehe Papoulis: "Random Processes"

	rabl2=convol(r,[-1,16,-30,16,-1]/12);		// Zweite Ableitung der Autokorrelierten
	nx=((2*NKO-1)+5)/2;
	RXX2_0=abs(rabl2(nx));

	n2=(NP/%pi) .*sqrt(RXX2_0/RXX0);
	n2=round(n2);					// Auf Grundlage der AKF geschtzte
	N2=[N2;n2];						// Nulldurchgangsanzahl
end

endfunction
