function [SSE,r,b] = polyfit(xx,yy,p)
//Polyfit	Calculates the polynomial fitting
// 
//	y^ = b(1) + b(2)*x + b(3)*x^2 + ... + b(p)*x^p
//
//given data sets xx, yy, and the polynomial degree p.
//Vectors xx and yy are row vectors.

[n m] = size(xx');

V = vandermonde(xx);   //Get Vandermonde matrix for xx

//Get matrix X for solution
if p == n-1 then
   X = V;
elseif p<n-1 then
   X = V(1:n,1:p+1);
else
  X = V;
  for k = n+1:p+1
      X = [X xx'^k]
  end
end;

//Calculating coefficients b, SSE, and r
b=inv(X'*X)*X'*yy';
yfit = X*b;
err = yy'-yfit;
SSE = err'*err;
ybar = sum(yy)/n;
ybarv = ybar*ones(n,1);
SST = norm(yy'-ybarv)^2;
r = sqrt(1-SSE/SST);

//end function

