function [Qratio,pr,km,qpr]=pwmratio(Q)	
// PWMRATIO
//		[Qout,PR,KM,QPR]=PWMRATIO(Q)
//
//		Pulswidth demodulation: the length of a group of 1's in a vector
//		is set to relation to the length of the 0-group before in the vector.
//
//		Example:
//
//		..0000001111000000011...
//		        --4-
//		  ---10-----
//
//			=> PR(1)=0.4
//			=> KM(1)=10
//			=> QPR=[0 0 0 0 0 0 0 0 0 0.4 0...]
//		       => Qout=[0 0 0 0 0 0 0 0 0 0.4 0.4 0.4,...]
//
//		Qout has the same length like the input vector Q.
//		On the falling edges of Q the ratio is updated.

LQ=length(Q);
ki0=findgrup(Q==0,1);
Nk0=size(ki0,2);
ki1=findgrup(Q==1,1);
Nk1=size(ki1,2);

if ki1(1,1)==1,				// Q-Folge startet mit 1
	ki1=ki1(:,2:Nk1);		// Fhrende 1 werden eliminiert
	Nk1=Nk1-1;
end
if ki0(2,Nk0)==LQ,			// Q-Folge endet mit 0
	ki0=ki0(:,1:Nk0-1);		// Abschlieende Nullen werden
	Nk0=Nk0-1;			// eliminiert.
end

dk0=mtlb_diff(ki0)+1;
dk1=mtlb_diff(ki1)+1;

if Nk0==Nk1,
	km=ki1(2,:);
	pr=dk1 ./(dk0+dk1);
	qpr=zeros(Q);
	qpr(km)=pr;
	Qratio=qpr;
	kres=findgrup(Qratio==0);	// Fhrende Nullen bilden keine Gruppe
	Nkres=size(kres,2);
	if Nkres>0,
		for p=1:1:Nkres,
			lakt=kres(2,p)-kres(1,p)+1;
			Qratio(kres(1,p):kres(2,p))=Qratio(kres(1,p)-1)*ones(1,lakt);
		end
	end
	kres2=findgrup(Qratio==0,1);
	if ~isempty(kres2),
		kres2=kres2(:,size(kres2,2));
		if kres2(1)~=1,
			Qratio(kres2(1):kres2(2))=Qratio(kres2(1,1)-1)*ones(1,kres2(2)-kres2(1)+1);
		end
	end
else
	km=[];
	pr=[];
end

endfunction