function [c,Xex,Yex,Prb]=schnitt(x,y)
// SCHNITT
//  [C,XEX,YEX,PRB]=SCHNITT(X,Y)
//
//  common elements of two matrices X and Y. The elements of X and Y must
//  be positive (elements of X and Y are rounded first !).
//		The result is a vector C, which contains the common numbers of X and Y.
//  The routine is based upon a comparison of the histograms, calculated with
//  dsearch.
//
//  Example:
//  a =[12    22     5     7    38    12    30    21]
//  b =[42     6    34     7    14    39    34    26    12    25]
//
//  [c,X,Y]=schnitt(a,b) leads to:
//
//  c =[ 7;   12]
//  X =[ 5;   21;   22;   30;   38];
//  Y =[ 6;   14;   25;   26;   34;   39;   42]
//		
//  XEX contains the numbers exclusively available in X,
//  YEX the numbers only available in Y.
//  TheVector PRB contains the probabilities
//  PRB=[P(Y<X), P(Y=X), P(Y>X)]

c=[];
Xex=[]; Yex=[]; Prb=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0);

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

x=round(x); y=round(y);	

maxwert=max(max(x),max(y));
minwert=min(min(x),min(y));

if minwert<1
	disp('Minimal values must be at least 1 !');
	return;
end


[zx,sx]=size(x); [zy,sy]=size(y);
nx=zx*sx; ny=zy*sy;
val=1:1:maxwert;

x=x(:).'; y=y(:).';

[indx,hisX,infx]=dsearch(x,val,"d");
[indy,hisY,infy]=dsearch(y,val,"d");

hisAND=hisX&hisY;
c=find(hisAND);
Xex=find(hisX&(~hisAND));
Yex=find(hisY&(~hisAND));
						// Substraktion von Zufallsvariablen

hisXFULL=[zeros(hisX),hisX];
hisYFULL=[hisY(:,$:-1:1),zeros(hisY)];

hisminus=convol(hisXFULL,hisYFULL);
hisminus=hisminus(length(hisX)+1:1:length(hisminus) - length(hisX));
kdiff=-floor(length(hisminus)/2):1:floor(length(hisminus)/2);
hisminus=hisminus ./sum(hisminus);

PSAME=hisminus(kdiff==0);
PyX=sum(hisminus(kdiff>0));
PYx=sum(hisminus(kdiff<0));
Prb=[PyX,PSAME,PYx];

endfunction
