function Q=schnittp(C1,C2);
//SCHNITTP	crossing points of two curves
//
//	Q=SCHNITTP(C1,C2)
//
//	C1,C2	: 	curves 1 and 2, defined by complex vectors 
//		Q	: 	matrix with 3 rows. the 2nd row contains the direction vector factor
//				and the last row the index ps of curve1, so that the crossing point
//				can be calculated by
//			       C1(ps) + Q(3,ps)*(C1(ps+1)-C1(ps))

[%nargout,%nargin]=argn(0);

Q=[];
flagcomplex=0;
if ~isreal(C1),
	C1=C1(:).';
	C1=[real(C1);imag(C1)];
	flagcomplex=1;
end
if ~isreal(C2),
	C2=C2(:).';
	C2=[real(C2);imag(C2)];
end

x=C1(1,:); y=C1(2,:);
u=C2(1,:); w=C2(2,:);

[X,U]=meshgrid(x,u);
[Y,W]=meshgrid(y,w);
[zxu,sxu]=size(X);
[zyw,syw]=size(Y);

DX=diff(X,1,'c');
DX=DX(1:zxu-1,1:1:sxu-1);
DY=diff(Y,1,'c');
DY=DY(1:zxu-1,1:1:sxu-1);
DU=diff(U,1,'r');
DU=DU(:,1:1:sxu-1);
DW=diff(W,1,'r');
DW=DW(:,1:1:sxu-1);
X=X(1:1:zxu-1,1:1:sxu-1);
Y=Y(1:1:zxu-1,1:1:sxu-1);
U=U(1:1:zxu-1,1:1:sxu-1);
W=W(1:1:zxu-1,1:1:sxu-1);

determi=DU .*DY - DX .*DW;
detlambda=DU .*(W - Y) - DW .*(U - X);
detgamma=DX .*(W - Y) - DY .*(U - X);
	
lambda=-ones(determi);
gam=-ones(determi);
lambda(determi~=0)=detlambda(determi~=0) ./determi(determi~=0);
gam(determi~=0)=detgamma(determi~=0) ./determi(determi~=0);

[pz,ps] = mtlb_find(bool2s(bool2s(bool2s(bool2s(mtlb_logic(mtlb_double(lambda),">=",0.000000000D+00))&bool2s(mtlb_logic(mtlb_double(lambda),"<=",1.000000000D+00)))&bool2s(mtlb_logic(mtlb_double(gam),">=",0.000000000D+00)))&bool2s(mtlb_logic(mtlb_double(gam),"<=",1.000000000D+00))));

if ~isempty(pz) then
	pz=pz(:).'; ps=ps(:).';
	[zxlam,sxlam]=size(lambda);
	lamsel=lambda(:).';
	elemnr=(ps-1) .*zxlam + pz;
	lamsel=lamsel(elemnr);
	XS=x(ps) + lamsel .*(x(ps+1)-x(ps));
	YS=y(ps) + lamsel .*(y(ps+1)-y(ps));

	if flagcomplex==1,
		Q=[(XS + %i .*YS);lamsel;ps];
	else
		Q=[XS;YS;lamsel;ps];
	end
end

endfunction