function [s,ABBMAT] = sirp(N,C,modusirp)
//SIRP Sherical invariant random processes
//
//	[S,ABBMAT]=SIRP(N,C,mode)
// 
//	N			: Number of samples of the random processes
//	C			: Co-Variance matrix (2 x 2) of the random processes
//	modusirp	: Modus-String. Valid entries are 'uniform' and 'normal'
//	s			: random processes, each column represents a signal 
//	ABBMAT		: transformation matrix.

// Ouput variables initialisation (not found in input variables)
s=[];
ABBMAT=[];

[%nargout,%nargin] = argn(0)	// Number of arguments in function call
mode(0);						// Display mode
ieee(1);						// Display warning for floating point exception

if %nargin==1 then				// checking arguments
  C = [1,0.3;0.3,0.5];			// Standard Co-Variance matrix
  modusirp = "normal";			// default Normal distribution
end;
if %nargin==2 then
  modusirp = "normal";
end;
flag=0;

modusirp=convstr(part(modusirp,1:2),'l');
if modusirp=="no" | modusirp=="ga" then
	flag=0;
else
	flag=1;
end

// rotation angle alpha, Variance X and Y
alpha=0.5*atan((2*C(1,2)),(C(1,1)-C(2,2)));
p11=cos(alpha)^2;
p12=sin(alpha)^2;
P = [p11,p12;p12,p11];

if cond(P)>1E4 then
  error("Bad Condition Matrix");
  s = [];
  ABBMAT = [];
  return;
end;
P = inv(P)*[C(1,1);C(2,2)];
if ((P(1)<=0) | (P(2)<=0)) then
  error("|co-variance| < geom. mean of variances");
  s = [];
  ABBMAT = [];
  return;
end;
sx = sqrt(abs(P(1)));	// standard dev. of
sy = sqrt(abs(P(2)));	// input processes

if flag==0 then			// Normal distribution
  x = sx .*rand(1,N,"normal");
  y = sy .*rand(1,N,"normal");
end;
if flag==1 then			// Uniform distribution
  x = (sx .*(2 .*rand(1,N)-1)) .*sqrt(3);
  y = (sy .*(2 .*rand(1,N)-1)) .*sqrt(3);
end;

s = x .*cos(alpha)-y .*sin(alpha)+%i .*(y .*cos(alpha)+x .*sin(alpha));

// Now, X and Y are only independent if:
//(a):sxsy=1, alpha any value
//(b):alpha=K*pi/2, sxsy any value

s = [real(s);imag(s)].';
ABBMAT = [cos(alpha),-sin(alpha);sin(alpha),cos(alpha)]*[sx,0;0,sy];
endfunction