function [csout] = splitvek(csin,N) 
//SPLITVEK  Splitting vector data
// 
//CSOUT=SPLITVEK(CSIN,N)
// 
//This function splits vector data in segments with maximum
//number N of samples.

// Ouput variables initialisation (not found in input variables)
csout=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

csout = []; // Output argument

if %nargin==1 then  // Default maximum no. of samples
  N = 20;
end;

[zc,sc] = size(mtlb_double(csin));  // Dimension vector data

ANAL = csanaly(csin);
pstart = ANAL(:,3);
pend = ANAL(:,4);

perc = 0;
percold = 0;

winID=waitbar(perc,'Splitting Done');


for k = 1:1:size(mtlb_double(ANAL),1)
  ps = mtlb_e(pstart,k);
  pe = mtlb_e(pend,k);
  vcakt = csin(:,mtlb_imp(mtlb_double(ps),1,mtlb_double(pe)));
  npoi = mtlb_a(mtlb_s(mtlb_double(pe),mtlb_double(ps)),1);
  // no. of samples of current vector

  if mtlb_logic(npoi,">",mtlb_s(2*mtlb_double(N),3)) then // Splitting will be done
   km1 = mtlb_imp(1,mtlb_double(N),mtlb_s(npoi,floor(mtlb_double(N)/2)));
   km2 = [km1(2:max(size(km1)))-1,npoi];
   ksplit = [km1;km2]; // Splitting Indices
  
   anzteil = size(ksplit,2);
   if anzteil>1 then
   
     for m = 1:1:anzteil
     //vector curves must contain the last point of last vector
     //and the 1st point of the next vector
      if bool2s(m>1)&bool2s(m<anzteil) then
        cakt = vcakt(:,ksplit(1,m):1:ksplit(1,m+1));
      end;
      if m==1 then
        cakt = vcakt(:,ksplit(1,m):1:ksplit(1,m+1));
      end;
      if m==anzteil then
        cakt = vcakt(:,ksplit(1,m):1:ksplit(2,m));
      end;
      // mtlb(cakt) can be replaced by cakt() or cakt whether cakt is an M-file or not
      head = [ANAL(k,1);size(mtlb_double(mtlb(cakt)),2);zeros(zc-2,1)];
      // mtlb(cakt) can be replaced by cakt() or cakt whether cakt is an M-file or not
      csout = [csout,head,mtlb(cakt)];
     end;
   else
     cakt = vcakt(:,ksplit(1,1):1:ksplit(2,1));
     head = [ANAL(k,1);size(mtlb_double(cakt),2);zeros(zc-2,1)];
     csout = [csout,head,cakt];
   end;
  else
    head = [ANAL(k,1);size(mtlb_double(vcakt),2);zeros(zc-2,1)];
    csout = [csout,head,vcakt];
  end;
  perc = round((100*k)/size(mtlb_double(ANAL),1));
  if perc>=(percold+1) then
    waitbar(perc/100,winID);
    percold = perc;
  end;
end;
csout=real(csout);
winclose(winID);
endfunction