function [spk,timeaxis,faxis] = timefreq(x,fs)
//TIMEFREQ
//[SPK,TIMEAXIS,FAXIS]=TIMEFREQ(X,Fs)
// 
//calculation of short time spectrograms
//of a time series
// 
//X: Time series (equidistant samples)
//Fs: sampling frequency
// 
//SPK: abs value of spectrogram
//TIMEAXIS: the time
//FAXIS: Ffrequency axis
// 
//for calculation of FFT 1024 samples are used.

// Ouput variables initialisation (not found in input variables)
spk=[];
timeaxis=[];
faxis=[];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

lx = max(size(mtlb_double(x)));      // length of time series
N = 256;                             // Sequence base length
ovlap = 64;                          // Overlapping samples
ntimes = floor(lx/N);                // time points
timeaxis = ((0:1:ntimes-1)*N)/mtlb_double(fs);  // time axis for spectrograms
xcut = mtlb_e(x,1:N*ntimes);                    // Cropping final values
xcut = matrix(mtlb_double(xcut),N,ntimes);      // conv. to matrix
xupper = [xcut(1:ovlap,2:ntimes),zeros(ovlap,1)];
xlower = [zeros(ovlap,1),xcut(N-ovlap+1:N,1:ntimes-1)];

xcut = [xlower;xcut;xupper];                    // Overlapping

spk = mtlb_fft(xcut);                           // FFT over each column
spk = abs(spk(1:floor((N+2*ovlap)/2),:));       // remove redundancy,
// frequency axis
faxis = (mtlb_double(fs)/(N+2*ovlap))*(0:1:floor((N+2*ovlap)/2)-1);
endfunction
