function [v] = vandermonde(x)
//VANDERMONDE	Produces the Vandermonde matrix based on vector x.
//If vector x has the components [x(1) x(2) ... x(n)],
//the corresponding Vandermonde matrix is written as:
//     [  1   x(1)  x(1)^2  x(1)^3 ... x(1)^(n-1) ]
//     [  1   x(2)  x(2)^2  x(2)^3 ... x(2)^(n-1) ]
//     [  .    .     .       .     ...  .         ]
//     [  .    .     .       .     ...  .         ]
//     [  1   x(n)  x(n)^2  x(n)^3 ... x(n)^(n-1) ]

[nx,mx] = size(x);
if nx<>1 & mx<>1 then
	error('Function vandermonde - input must be a vector');
	abort;
end;

if nx == 1 then
	u = x';
	n = mx;
else
	u = x;
	n = nx;
end;

// u = column vector = [x(1) x(2) ... x(n)]'
// n = number of elements in u
// v = first column of Vandermonde matrix (all ones)

v = ones(n,1);

for k = 1:(n-1)
	v = [v,u^k];
end;

//end function