function [H,W] = welch(xf,N) 
// WELCH Spektrum Estimation by Welch !
// 
//[H,W]=WELCH(XF,N)
// 
//XF: Time Series as vector
//N: segment size
//the segments are overlapping for N/2 values.
//N is a dual power. Default for N=1024
// 
//1): [H,W]=welch(xf);=> N=1024
//2): [H,W]=welch(xf,N);


// Ouput variables initialisation (not found in input variables)
H=[];
W=[];

// Number of arguments in function call
[%nargout,%nargin] = argn(0)

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if %nargin==1 then
  // Argument check
  N = 1024;
end;

if mtlb_logic(2^mtlb_double(nextpow2(N)),"~=",mtlb_double(N)) then
  N = 2^mtlb_s(mtlb_double(nextpow2(N)),1);
end;

ovl = mtlb_double(N)/4;      // number of overlapping values
N = mtlb_double(N)/2;

xf = overlapp(xf,N,ovl);
[K,L] = size(mtlb_double(xf));
// K: Anzahl der Teilfolgen
// L: Lnge einer Teilfolge

winl=window('hm',L);          // Windowing of each segment
A=sum(winl .^2) ./L;
winl=meshgrid(winl,1:1:K);
xf=xf .*winl;

SP = mtlb_fft(mtlb_double(mtlb_0(xf))).';
SP = mean((abs(SP) .^2),'r') ./A;
// Averaging and correction by window factor

H = sqrt(SP(1:L/2) ./L);
W = 0:(2*%pi)/L:%pi-(2*%pi)/L;
endfunction
