function anzwerk=werktage(Q0,bdg,kath);
// WERKTAGE	No. of working days within two dates
//
//		ANZWERK=WERKTAGE(Q0,BUNDLA,KATH)
//
//		meaning of variables:
//		---------------------
//		Q0		:	Date Matrix. 1st row contains start date, the 2nd the end date.
//					The columns are sorted in the order [day,month,year]
//
//		BUNDLA	:	String with abbreviation of a german country (see also FEIERTAG.M),
//					default is 'HES' for Hessen.
//
//		KATH	:	1 for catholic regions (having more celeb days)
//
//		ANZWERK	:	No. of working days (incl. start and end date)
//					The dates 24.12. and 31.12 are counted with a half working day,
//					when they are not on saturday or sunday.

[%nargout,%nargin]=argn(0);

if %nargin==1 then,
	bdg='hes';					// default HESSEN
	kath=0;						// default: not catholic
end
if %nargin==2 then, kath=0; end
if size(Q0,1)==1 then,
	Q0=[Q0;Q0];
end							// if only one date is given, he is,
							// checked on celeb day.

j1=Q0(1,3); j2=Q0(2,3);
if j2<j1,
	disp('	Das Enddatum mu zeitlich hinter');
	disp('	dem Anfangsdatum liegen !');
	return;
end
														// celeb day list
if j1==j2,												// --------------
	[FTN,Qf,wota]=feiertag(j1,bdg,kath);				// single year
else
	FTN=[]; Qf=[];wota=[];
	jax=j1:1:j2;
	for k=1:1:length(jax);								// several years
		[FTNakt,Qfakt,wotaakt]=feiertag(jax(k),bdg,kath);
		FTN=[FTN;FTNakt];
		Qf=[Qf;Qfakt];
		wota=[wota;wotaakt];
	end
end

NFT=size(Qf,1);								// number of celeb days
		
Qs=Q0(1,:); Qe=Q0(2,:);
Qe=calcdat(Qe,1);

Qakt=Qs; anzwerk=0;							// Initialize
while sum(abs(Qakt-Qe))~=0,
	dayakt=date2day(Qakt($:-1:1));				// current working day
	dayakt=mtlb_lower(part(dayakt,1:2));
	dista1=sum(abs(Qf - meshgrid(Qakt,1:1:NFT)).','r');
	if ~(mtlb_any(dista1==0) | min(bool2s(dayakt=='sa'),'r') | min(bool2s(dayakt=='su'),'r')),
		anzwerk=anzwerk+1;
	end
	if min(bool2s(Qakt(1:2)==[24,12])) & isempty(mtlb_findstr(dayakt,'sa')) & isempty(mtlb_findstr(dayakt,'su')),
		anzwerk=anzwerk+0.5;
	end
	if min(bool2s(Qakt(1:2)==[31,12])) & isempty(mtlb_findstr(dayakt,'sa')) & isempty(mtlb_findstr(dayakt,'su')),
		anzwerk=anzwerk+0.5;
	end
	Qakt=calcdat(Qakt,1);
end	

endfunction